searchData={"items":[{"type":"module","title":"FFmpex","doc":"Create and execute ffmpeg CLI commands.\n\nThe API is a builder, building up the list of options\nper-file, per-stream(-per-file), and globally.\n\nNote that adding options is backwards from using\nthe ffmpeg CLI; when using ffmpeg CLI, you specify the options\nbefore each file.\nBut with FFmpex (this library), you add the file/stream first, then\nadd the relevant options afterward.","ref":"FFmpex.html"},{"type":"module","title":"Example - FFmpex","doc":"import FFmpex\n    use FFmpex.Options\n\n    command =\n      FFmpex.new_command\n      |> add_global_option(option_y())\n      |> add_input_file(\"/path/to/input.avi\")\n      |> add_output_file(\"/path/to/output.avi\")\n        |> add_stream_specifier(stream_type: :video)\n          |> add_stream_option(option_b(\"64k\"))\n        |> add_file_option(option_maxrate(\"128k\"))\n        |> add_file_option(option_bufsize(\"64k\"))\n\n    :ok = execute(command)","ref":"FFmpex.html#module-example"},{"type":"function","title":"FFmpex.add_file_option/2","doc":"Add a per-file option to the command.\n\nApplies to the most recently added file.","ref":"FFmpex.html#add_file_option/2"},{"type":"function","title":"FFmpex.add_global_option/2","doc":"Add a global option that applies to the entire command.","ref":"FFmpex.html#add_global_option/2"},{"type":"function","title":"FFmpex.add_input_file/2","doc":"Add an input file to the command.","ref":"FFmpex.html#add_input_file/2"},{"type":"function","title":"FFmpex.add_output_file/2","doc":"Add an output file to the command.","ref":"FFmpex.html#add_output_file/2"},{"type":"function","title":"FFmpex.add_stream_option/2","doc":"Add a per-stream option to the command.\n\nApplies to the most recently added stream specifier, of the most recently added file.","ref":"FFmpex.html#add_stream_option/2"},{"type":"function","title":"FFmpex.add_stream_specifier/2","doc":"Add a stream specifier to the most recent file.\nThe stream specifier is used as a target for per-stream options.","ref":"FFmpex.html#add_stream_specifier/2"},{"type":"function","title":"Example - FFmpex.add_stream_specifier/2","doc":"add_stream_specifier(command, stream_type: :video)","ref":"FFmpex.html#add_stream_specifier/2-example"},{"type":"function","title":"Options - FFmpex.add_stream_specifier/2","doc":"* `:stream_index` - 0-based integer index for the stream\n* `:stream_type` - One of `:video`, `:video_without_pics`, `:audio`, `:subtitle`, `:data`, `:attachments`\n* `:program_id` - ID for the program\n* `:stream_id` - Stream id (e.g. PID in MPEG-TS container)\n* `:metadata_key` - Match streams with the given metadata tag\n* `:metadata_value` - Match streams with the given metadata value. Must also specify `:metadata_key`.\n* `:usable` - Matches streams with usable configuration, the codec must be defined and the essential information such as video dimension or audio sample rate must be present.","ref":"FFmpex.html#add_stream_specifier/2-options"},{"type":"function","title":"FFmpex.execute/1","doc":"Execute the command using ffmpeg CLI.\n\nReturns `{:ok, output}` on success, or `{:error, {cmd_output, exit_status}}` on error.","ref":"FFmpex.html#execute/1"},{"type":"function","title":"FFmpex.new_command/0","doc":"Begin a new blank (no options) ffmpeg command.","ref":"FFmpex.html#new_command/0"},{"type":"function","title":"FFmpex.prepare/1","doc":"Prepares the command to be executed, by converting the `%Command{}` into\nproper parameters to be feeded to `System.cmd/3` or `Port.open/2`.\n\nUnder normal circumstances `FFmpex.execute/1` should be used, use `prepare`\nonly when converted args are needed to be feeded in a custom execution method.\n\nReturns `{ffmpeg_executable_path, list_of_args}`.","ref":"FFmpex.html#prepare/1"},{"type":"function","title":"FFmpex.to_stdout/1","doc":"Outputs to stdout, so it can be used directly from `execute/1`'s output\n\n##### this option cannot be used with output files","ref":"FFmpex.html#to_stdout/1"},{"type":"module","title":"FFmpex.Options","doc":"Convenience to import all FFmpex options.\n\n```\nuse FFmpex.Options\n```","ref":"FFmpex.Options.html"},{"type":"module","title":"FFmpex.Options.Advanced","doc":"https://ffmpeg.org/ffmpeg-all.html#Advanced-options","ref":"FFmpex.Options.Advanced.html"},{"type":"function","title":"FFmpex.Options.Advanced.option_abort_on/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_abort_on/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_abort_on/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_abort_on/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_accurate_seek/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_accurate_seek/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_accurate_seek/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_accurate_seek/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_async/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_async/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_async/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_async/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_benchmark/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_benchmark/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_benchmark/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_benchmark/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_benchmark_all/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_benchmark_all/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_benchmark_all/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_benchmark_all/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_bsf/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_bsf/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_bsf/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_bsf/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_copy_unknown/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_copy_unknown/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_copy_unknown/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_copy_unknown/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_copytb/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_copytb/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_copytb/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_copytb/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_copyts/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_copyts/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_copyts/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_copyts/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_discard/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_discard/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_discard/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_discard/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_dts_delta_threshold/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_dts_delta_threshold/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_dts_delta_threshold/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_dts_delta_threshold/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_dump/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_dump/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_dump/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_dump/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex_script/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex_script/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex_script/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex_script/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex_threads/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex_threads/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_filter_complex_threads/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_filter_complex_threads/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_frame_drop_threshold/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_frame_drop_threshold/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_frame_drop_threshold/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_frame_drop_threshold/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_hex/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_hex/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_hex/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_hex/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_ignore_unknown/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_ignore_unknown/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_ignore_unknown/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_ignore_unknown/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_lavfi/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_lavfi/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_lavfi/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_lavfi/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_loop/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_loop/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_loop/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_loop/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_map/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_map/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_map/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_map/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_channel/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_channel/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_channel/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_channel/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_chapters/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_chapters/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_chapters/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_chapters/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_metadata/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_metadata/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_map_metadata/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_map_metadata/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_max_muxing_queue_size/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_max_muxing_queue_size/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_max_muxing_queue_size/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_max_muxing_queue_size/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_muxdelay/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_muxdelay/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_muxdelay/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_muxdelay/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_muxpreload/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_muxpreload/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_muxpreload/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_muxpreload/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_override_ffserver/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_override_ffserver/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_override_ffserver/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_override_ffserver/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_re/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_re/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_re/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_re/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_sdp_file/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_sdp_file/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_sdp_file/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_sdp_file/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_seek_timestamp/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_seek_timestamp/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_seek_timestamp/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_seek_timestamp/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_shortest/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_shortest/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_shortest/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_shortest/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_start_at_zero/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_start_at_zero/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_start_at_zero/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_start_at_zero/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_streamid/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_streamid/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_streamid/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_streamid/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_tag/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_tag/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_tag/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_tag/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_thread_queue_size/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_thread_queue_size/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_thread_queue_size/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_thread_queue_size/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_timecode/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_timecode/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_timecode/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_timecode/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_timelimit/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_timelimit/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_timelimit/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_timelimit/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_vsync/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_vsync/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_vsync/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_vsync/1"},{"type":"function","title":"FFmpex.Options.Advanced.option_xerror/0","doc":"","ref":"FFmpex.Options.Advanced.html#option_xerror/0"},{"type":"function","title":"FFmpex.Options.Advanced.option_xerror/1","doc":"","ref":"FFmpex.Options.Advanced.html#option_xerror/1"},{"type":"module","title":"FFmpex.Options.Audio","doc":"https://ffmpeg.org/ffmpeg-all.html#Audio-Options","ref":"FFmpex.Options.Audio.html"},{"type":"function","title":"FFmpex.Options.Audio.option_absf/0","doc":"","ref":"FFmpex.Options.Audio.html#option_absf/0"},{"type":"function","title":"FFmpex.Options.Audio.option_absf/1","doc":"","ref":"FFmpex.Options.Audio.html#option_absf/1"},{"type":"function","title":"FFmpex.Options.Audio.option_ac/0","doc":"","ref":"FFmpex.Options.Audio.html#option_ac/0"},{"type":"function","title":"FFmpex.Options.Audio.option_ac/1","doc":"","ref":"FFmpex.Options.Audio.html#option_ac/1"},{"type":"function","title":"FFmpex.Options.Audio.option_acodec/0","doc":"","ref":"FFmpex.Options.Audio.html#option_acodec/0"},{"type":"function","title":"FFmpex.Options.Audio.option_acodec/1","doc":"","ref":"FFmpex.Options.Audio.html#option_acodec/1"},{"type":"function","title":"FFmpex.Options.Audio.option_af/0","doc":"","ref":"FFmpex.Options.Audio.html#option_af/0"},{"type":"function","title":"FFmpex.Options.Audio.option_af/1","doc":"","ref":"FFmpex.Options.Audio.html#option_af/1"},{"type":"function","title":"FFmpex.Options.Audio.option_aframes/0","doc":"","ref":"FFmpex.Options.Audio.html#option_aframes/0"},{"type":"function","title":"FFmpex.Options.Audio.option_aframes/1","doc":"","ref":"FFmpex.Options.Audio.html#option_aframes/1"},{"type":"function","title":"FFmpex.Options.Audio.option_an/0","doc":"","ref":"FFmpex.Options.Audio.html#option_an/0"},{"type":"function","title":"FFmpex.Options.Audio.option_an/1","doc":"","ref":"FFmpex.Options.Audio.html#option_an/1"},{"type":"function","title":"FFmpex.Options.Audio.option_aq/0","doc":"","ref":"FFmpex.Options.Audio.html#option_aq/0"},{"type":"function","title":"FFmpex.Options.Audio.option_aq/1","doc":"","ref":"FFmpex.Options.Audio.html#option_aq/1"},{"type":"function","title":"FFmpex.Options.Audio.option_ar/0","doc":"","ref":"FFmpex.Options.Audio.html#option_ar/0"},{"type":"function","title":"FFmpex.Options.Audio.option_ar/1","doc":"","ref":"FFmpex.Options.Audio.html#option_ar/1"},{"type":"function","title":"FFmpex.Options.Audio.option_atag/0","doc":"","ref":"FFmpex.Options.Audio.html#option_atag/0"},{"type":"function","title":"FFmpex.Options.Audio.option_atag/1","doc":"","ref":"FFmpex.Options.Audio.html#option_atag/1"},{"type":"function","title":"FFmpex.Options.Audio.option_guess_layout_max/0","doc":"","ref":"FFmpex.Options.Audio.html#option_guess_layout_max/0"},{"type":"function","title":"FFmpex.Options.Audio.option_guess_layout_max/1","doc":"","ref":"FFmpex.Options.Audio.html#option_guess_layout_max/1"},{"type":"function","title":"FFmpex.Options.Audio.option_sample_fmt/0","doc":"","ref":"FFmpex.Options.Audio.html#option_sample_fmt/0"},{"type":"function","title":"FFmpex.Options.Audio.option_sample_fmt/1","doc":"","ref":"FFmpex.Options.Audio.html#option_sample_fmt/1"},{"type":"module","title":"FFmpex.Options.Devices.Libavdevice","doc":"https://www.ffmpeg.org/ffmpeg-devices.html","ref":"FFmpex.Options.Devices.Libavdevice.html"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_draw_mouse/0","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_draw_mouse/0"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_draw_mouse/1","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_draw_mouse/1"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_framerate/0","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_framerate/0"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_framerate/1","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_framerate/1"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_video_size/0","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_video_size/0"},{"type":"function","title":"FFmpex.Options.Devices.Libavdevice.option_video_size/1","doc":"","ref":"FFmpex.Options.Devices.Libavdevice.html#option_video_size/1"},{"type":"module","title":"FFmpex.Options.Formats.Image2","doc":"https://www.ffmpeg.org/ffmpeg-formats.html#image2-1","ref":"FFmpex.Options.Formats.Image2.html"},{"type":"function","title":"FFmpex.Options.Formats.Image2.option_pattern_type/0","doc":"","ref":"FFmpex.Options.Formats.Image2.html#option_pattern_type/0"},{"type":"function","title":"FFmpex.Options.Formats.Image2.option_pattern_type/1","doc":"","ref":"FFmpex.Options.Formats.Image2.html#option_pattern_type/1"},{"type":"module","title":"FFmpex.Options.Main","doc":"https://ffmpeg.org/ffmpeg-all.html#Main-options","ref":"FFmpex.Options.Main.html"},{"type":"function","title":"FFmpex.Options.Main.option_attach/0","doc":"","ref":"FFmpex.Options.Main.html#option_attach/0"},{"type":"function","title":"FFmpex.Options.Main.option_attach/1","doc":"","ref":"FFmpex.Options.Main.html#option_attach/1"},{"type":"function","title":"FFmpex.Options.Main.option_c/0","doc":"","ref":"FFmpex.Options.Main.html#option_c/0"},{"type":"function","title":"FFmpex.Options.Main.option_c/1","doc":"","ref":"FFmpex.Options.Main.html#option_c/1"},{"type":"function","title":"FFmpex.Options.Main.option_codec/0","doc":"","ref":"FFmpex.Options.Main.html#option_codec/0"},{"type":"function","title":"FFmpex.Options.Main.option_codec/1","doc":"","ref":"FFmpex.Options.Main.html#option_codec/1"},{"type":"function","title":"FFmpex.Options.Main.option_debug_ts/0","doc":"","ref":"FFmpex.Options.Main.html#option_debug_ts/0"},{"type":"function","title":"FFmpex.Options.Main.option_debug_ts/1","doc":"","ref":"FFmpex.Options.Main.html#option_debug_ts/1"},{"type":"function","title":"FFmpex.Options.Main.option_dframes/0","doc":"","ref":"FFmpex.Options.Main.html#option_dframes/0"},{"type":"function","title":"FFmpex.Options.Main.option_dframes/1","doc":"","ref":"FFmpex.Options.Main.html#option_dframes/1"},{"type":"function","title":"FFmpex.Options.Main.option_disposition/0","doc":"","ref":"FFmpex.Options.Main.html#option_disposition/0"},{"type":"function","title":"FFmpex.Options.Main.option_disposition/1","doc":"","ref":"FFmpex.Options.Main.html#option_disposition/1"},{"type":"function","title":"FFmpex.Options.Main.option_dump_attachment/0","doc":"","ref":"FFmpex.Options.Main.html#option_dump_attachment/0"},{"type":"function","title":"FFmpex.Options.Main.option_dump_attachment/1","doc":"","ref":"FFmpex.Options.Main.html#option_dump_attachment/1"},{"type":"function","title":"FFmpex.Options.Main.option_f/0","doc":"","ref":"FFmpex.Options.Main.html#option_f/0"},{"type":"function","title":"FFmpex.Options.Main.option_f/1","doc":"","ref":"FFmpex.Options.Main.html#option_f/1"},{"type":"function","title":"FFmpex.Options.Main.option_filter/0","doc":"","ref":"FFmpex.Options.Main.html#option_filter/0"},{"type":"function","title":"FFmpex.Options.Main.option_filter/1","doc":"","ref":"FFmpex.Options.Main.html#option_filter/1"},{"type":"function","title":"FFmpex.Options.Main.option_filter_script/0","doc":"","ref":"FFmpex.Options.Main.html#option_filter_script/0"},{"type":"function","title":"FFmpex.Options.Main.option_filter_script/1","doc":"","ref":"FFmpex.Options.Main.html#option_filter_script/1"},{"type":"function","title":"FFmpex.Options.Main.option_filter_threads/0","doc":"","ref":"FFmpex.Options.Main.html#option_filter_threads/0"},{"type":"function","title":"FFmpex.Options.Main.option_filter_threads/1","doc":"","ref":"FFmpex.Options.Main.html#option_filter_threads/1"},{"type":"function","title":"FFmpex.Options.Main.option_frames/0","doc":"","ref":"FFmpex.Options.Main.html#option_frames/0"},{"type":"function","title":"FFmpex.Options.Main.option_frames/1","doc":"","ref":"FFmpex.Options.Main.html#option_frames/1"},{"type":"function","title":"FFmpex.Options.Main.option_fs/0","doc":"","ref":"FFmpex.Options.Main.html#option_fs/0"},{"type":"function","title":"FFmpex.Options.Main.option_fs/1","doc":"","ref":"FFmpex.Options.Main.html#option_fs/1"},{"type":"function","title":"FFmpex.Options.Main.option_i/0","doc":"","ref":"FFmpex.Options.Main.html#option_i/0"},{"type":"function","title":"FFmpex.Options.Main.option_i/1","doc":"","ref":"FFmpex.Options.Main.html#option_i/1"},{"type":"function","title":"FFmpex.Options.Main.option_itsoffset/0","doc":"","ref":"FFmpex.Options.Main.html#option_itsoffset/0"},{"type":"function","title":"FFmpex.Options.Main.option_itsoffset/1","doc":"","ref":"FFmpex.Options.Main.html#option_itsoffset/1"},{"type":"function","title":"FFmpex.Options.Main.option_metadata/0","doc":"","ref":"FFmpex.Options.Main.html#option_metadata/0"},{"type":"function","title":"FFmpex.Options.Main.option_metadata/1","doc":"","ref":"FFmpex.Options.Main.html#option_metadata/1"},{"type":"function","title":"FFmpex.Options.Main.option_n/0","doc":"","ref":"FFmpex.Options.Main.html#option_n/0"},{"type":"function","title":"FFmpex.Options.Main.option_n/1","doc":"","ref":"FFmpex.Options.Main.html#option_n/1"},{"type":"function","title":"FFmpex.Options.Main.option_pre/0","doc":"","ref":"FFmpex.Options.Main.html#option_pre/0"},{"type":"function","title":"FFmpex.Options.Main.option_pre/1","doc":"","ref":"FFmpex.Options.Main.html#option_pre/1"},{"type":"function","title":"FFmpex.Options.Main.option_program/0","doc":"","ref":"FFmpex.Options.Main.html#option_program/0"},{"type":"function","title":"FFmpex.Options.Main.option_program/1","doc":"","ref":"FFmpex.Options.Main.html#option_program/1"},{"type":"function","title":"FFmpex.Options.Main.option_progress/0","doc":"","ref":"FFmpex.Options.Main.html#option_progress/0"},{"type":"function","title":"FFmpex.Options.Main.option_progress/1","doc":"","ref":"FFmpex.Options.Main.html#option_progress/1"},{"type":"function","title":"FFmpex.Options.Main.option_q/0","doc":"","ref":"FFmpex.Options.Main.html#option_q/0"},{"type":"function","title":"FFmpex.Options.Main.option_q/1","doc":"","ref":"FFmpex.Options.Main.html#option_q/1"},{"type":"function","title":"FFmpex.Options.Main.option_qscale/0","doc":"","ref":"FFmpex.Options.Main.html#option_qscale/0"},{"type":"function","title":"FFmpex.Options.Main.option_qscale/1","doc":"","ref":"FFmpex.Options.Main.html#option_qscale/1"},{"type":"function","title":"FFmpex.Options.Main.option_ss/0","doc":"","ref":"FFmpex.Options.Main.html#option_ss/0"},{"type":"function","title":"FFmpex.Options.Main.option_ss/1","doc":"","ref":"FFmpex.Options.Main.html#option_ss/1"},{"type":"function","title":"FFmpex.Options.Main.option_sseof/0","doc":"","ref":"FFmpex.Options.Main.html#option_sseof/0"},{"type":"function","title":"FFmpex.Options.Main.option_sseof/1","doc":"","ref":"FFmpex.Options.Main.html#option_sseof/1"},{"type":"function","title":"FFmpex.Options.Main.option_stats/0","doc":"","ref":"FFmpex.Options.Main.html#option_stats/0"},{"type":"function","title":"FFmpex.Options.Main.option_stats/1","doc":"","ref":"FFmpex.Options.Main.html#option_stats/1"},{"type":"function","title":"FFmpex.Options.Main.option_stdin/0","doc":"","ref":"FFmpex.Options.Main.html#option_stdin/0"},{"type":"function","title":"FFmpex.Options.Main.option_stdin/1","doc":"","ref":"FFmpex.Options.Main.html#option_stdin/1"},{"type":"function","title":"FFmpex.Options.Main.option_stream_loop/0","doc":"","ref":"FFmpex.Options.Main.html#option_stream_loop/0"},{"type":"function","title":"FFmpex.Options.Main.option_stream_loop/1","doc":"","ref":"FFmpex.Options.Main.html#option_stream_loop/1"},{"type":"function","title":"FFmpex.Options.Main.option_t/0","doc":"","ref":"FFmpex.Options.Main.html#option_t/0"},{"type":"function","title":"FFmpex.Options.Main.option_t/1","doc":"","ref":"FFmpex.Options.Main.html#option_t/1"},{"type":"function","title":"FFmpex.Options.Main.option_target/0","doc":"","ref":"FFmpex.Options.Main.html#option_target/0"},{"type":"function","title":"FFmpex.Options.Main.option_target/1","doc":"","ref":"FFmpex.Options.Main.html#option_target/1"},{"type":"function","title":"FFmpex.Options.Main.option_timestamp/0","doc":"","ref":"FFmpex.Options.Main.html#option_timestamp/0"},{"type":"function","title":"FFmpex.Options.Main.option_timestamp/1","doc":"","ref":"FFmpex.Options.Main.html#option_timestamp/1"},{"type":"function","title":"FFmpex.Options.Main.option_to/0","doc":"","ref":"FFmpex.Options.Main.html#option_to/0"},{"type":"function","title":"FFmpex.Options.Main.option_to/1","doc":"","ref":"FFmpex.Options.Main.html#option_to/1"},{"type":"function","title":"FFmpex.Options.Main.option_y/0","doc":"","ref":"FFmpex.Options.Main.html#option_y/0"},{"type":"function","title":"FFmpex.Options.Main.option_y/1","doc":"","ref":"FFmpex.Options.Main.html#option_y/1"},{"type":"module","title":"FFmpex.Options.Muxers","doc":"https://ffmpeg.org/ffmpeg-all.html#Muxers","ref":"FFmpex.Options.Muxers.html"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_base_url/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_base_url/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_base_url/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_base_url/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_flags/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_flags/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_flags/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_flags/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_init_time/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_init_time/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_init_time/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_init_time/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_list_size/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_list_size/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_list_size/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_list_size/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_playlist_type/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_playlist_type/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_playlist_type/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_playlist_type/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_segment_filename/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_segment_filename/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_segment_filename/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_segment_filename/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_segment_type/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_segment_type/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_segment_type/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_segment_type/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_time/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_time/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_hls_time/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_hls_time/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_master_pl_name/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_master_pl_name/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_master_pl_name/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_master_pl_name/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_format/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_format/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_format/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_format/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_list/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_list/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_list/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_list/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_time/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_time/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_segment_time/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_segment_time/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_start_number/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_start_number/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_start_number/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_start_number/1"},{"type":"function","title":"FFmpex.Options.Muxers.option_var_stream_map/0","doc":"","ref":"FFmpex.Options.Muxers.html#option_var_stream_map/0"},{"type":"function","title":"FFmpex.Options.Muxers.option_var_stream_map/1","doc":"","ref":"FFmpex.Options.Muxers.html#option_var_stream_map/1"},{"type":"module","title":"FFmpex.Options.Subtitle","doc":"https://ffmpeg.org/ffmpeg-all.html#Subtitle-options","ref":"FFmpex.Options.Subtitle.html"},{"type":"function","title":"FFmpex.Options.Subtitle.option_canvas_size/0","doc":"","ref":"FFmpex.Options.Subtitle.html#option_canvas_size/0"},{"type":"function","title":"FFmpex.Options.Subtitle.option_canvas_size/1","doc":"","ref":"FFmpex.Options.Subtitle.html#option_canvas_size/1"},{"type":"function","title":"FFmpex.Options.Subtitle.option_fix_sub_duration/0","doc":"","ref":"FFmpex.Options.Subtitle.html#option_fix_sub_duration/0"},{"type":"function","title":"FFmpex.Options.Subtitle.option_fix_sub_duration/1","doc":"","ref":"FFmpex.Options.Subtitle.html#option_fix_sub_duration/1"},{"type":"function","title":"FFmpex.Options.Subtitle.option_sbsf/0","doc":"","ref":"FFmpex.Options.Subtitle.html#option_sbsf/0"},{"type":"function","title":"FFmpex.Options.Subtitle.option_sbsf/1","doc":"","ref":"FFmpex.Options.Subtitle.html#option_sbsf/1"},{"type":"function","title":"FFmpex.Options.Subtitle.option_scodec/0","doc":"","ref":"FFmpex.Options.Subtitle.html#option_scodec/0"},{"type":"function","title":"FFmpex.Options.Subtitle.option_scodec/1","doc":"","ref":"FFmpex.Options.Subtitle.html#option_scodec/1"},{"type":"function","title":"FFmpex.Options.Subtitle.option_sn/0","doc":"","ref":"FFmpex.Options.Subtitle.html#option_sn/0"},{"type":"function","title":"FFmpex.Options.Subtitle.option_sn/1","doc":"","ref":"FFmpex.Options.Subtitle.html#option_sn/1"},{"type":"module","title":"FFmpex.Options.Video","doc":"https://ffmpeg.org/ffmpeg-all.html#Video-Options","ref":"FFmpex.Options.Video.html"},{"type":"function","title":"FFmpex.Options.Video.option_aspect/0","doc":"","ref":"FFmpex.Options.Video.html#option_aspect/0"},{"type":"function","title":"FFmpex.Options.Video.option_aspect/1","doc":"","ref":"FFmpex.Options.Video.html#option_aspect/1"},{"type":"function","title":"FFmpex.Options.Video.option_copyinkf/0","doc":"","ref":"FFmpex.Options.Video.html#option_copyinkf/0"},{"type":"function","title":"FFmpex.Options.Video.option_copyinkf/1","doc":"","ref":"FFmpex.Options.Video.html#option_copyinkf/1"},{"type":"function","title":"FFmpex.Options.Video.option_dc/0","doc":"","ref":"FFmpex.Options.Video.html#option_dc/0"},{"type":"function","title":"FFmpex.Options.Video.option_dc/1","doc":"","ref":"FFmpex.Options.Video.html#option_dc/1"},{"type":"function","title":"FFmpex.Options.Video.option_force_key_frames/0","doc":"","ref":"FFmpex.Options.Video.html#option_force_key_frames/0"},{"type":"function","title":"FFmpex.Options.Video.option_force_key_frames/1","doc":"","ref":"FFmpex.Options.Video.html#option_force_key_frames/1"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccel/0","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccel/0"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccel/1","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccel/1"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccel_device/0","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccel_device/0"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccel_device/1","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccel_device/1"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccels/0","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccels/0"},{"type":"function","title":"FFmpex.Options.Video.option_hwaccels/1","doc":"","ref":"FFmpex.Options.Video.html#option_hwaccels/1"},{"type":"function","title":"FFmpex.Options.Video.option_ilme/0","doc":"","ref":"FFmpex.Options.Video.html#option_ilme/0"},{"type":"function","title":"FFmpex.Options.Video.option_ilme/1","doc":"","ref":"FFmpex.Options.Video.html#option_ilme/1"},{"type":"function","title":"FFmpex.Options.Video.option_noautorotate/0","doc":"","ref":"FFmpex.Options.Video.html#option_noautorotate/0"},{"type":"function","title":"FFmpex.Options.Video.option_noautorotate/1","doc":"","ref":"FFmpex.Options.Video.html#option_noautorotate/1"},{"type":"function","title":"FFmpex.Options.Video.option_pass/0","doc":"","ref":"FFmpex.Options.Video.html#option_pass/0"},{"type":"function","title":"FFmpex.Options.Video.option_pass/1","doc":"","ref":"FFmpex.Options.Video.html#option_pass/1"},{"type":"function","title":"FFmpex.Options.Video.option_passlogfile/0","doc":"","ref":"FFmpex.Options.Video.html#option_passlogfile/0"},{"type":"function","title":"FFmpex.Options.Video.option_passlogfile/1","doc":"","ref":"FFmpex.Options.Video.html#option_passlogfile/1"},{"type":"function","title":"FFmpex.Options.Video.option_pix_fmt/0","doc":"","ref":"FFmpex.Options.Video.html#option_pix_fmt/0"},{"type":"function","title":"FFmpex.Options.Video.option_pix_fmt/1","doc":"","ref":"FFmpex.Options.Video.html#option_pix_fmt/1"},{"type":"function","title":"FFmpex.Options.Video.option_psnr/0","doc":"","ref":"FFmpex.Options.Video.html#option_psnr/0"},{"type":"function","title":"FFmpex.Options.Video.option_psnr/1","doc":"","ref":"FFmpex.Options.Video.html#option_psnr/1"},{"type":"function","title":"FFmpex.Options.Video.option_qphist/0","doc":"","ref":"FFmpex.Options.Video.html#option_qphist/0"},{"type":"function","title":"FFmpex.Options.Video.option_qphist/1","doc":"","ref":"FFmpex.Options.Video.html#option_qphist/1"},{"type":"function","title":"FFmpex.Options.Video.option_r/0","doc":"","ref":"FFmpex.Options.Video.html#option_r/0"},{"type":"function","title":"FFmpex.Options.Video.option_r/1","doc":"","ref":"FFmpex.Options.Video.html#option_r/1"},{"type":"function","title":"FFmpex.Options.Video.option_rc_override/0","doc":"","ref":"FFmpex.Options.Video.html#option_rc_override/0"},{"type":"function","title":"FFmpex.Options.Video.option_rc_override/1","doc":"","ref":"FFmpex.Options.Video.html#option_rc_override/1"},{"type":"function","title":"FFmpex.Options.Video.option_s/0","doc":"","ref":"FFmpex.Options.Video.html#option_s/0"},{"type":"function","title":"FFmpex.Options.Video.option_s/1","doc":"","ref":"FFmpex.Options.Video.html#option_s/1"},{"type":"function","title":"FFmpex.Options.Video.option_sws_flags/0","doc":"","ref":"FFmpex.Options.Video.html#option_sws_flags/0"},{"type":"function","title":"FFmpex.Options.Video.option_sws_flags/1","doc":"","ref":"FFmpex.Options.Video.html#option_sws_flags/1"},{"type":"function","title":"FFmpex.Options.Video.option_top/0","doc":"","ref":"FFmpex.Options.Video.html#option_top/0"},{"type":"function","title":"FFmpex.Options.Video.option_top/1","doc":"","ref":"FFmpex.Options.Video.html#option_top/1"},{"type":"function","title":"FFmpex.Options.Video.option_vbsf/0","doc":"","ref":"FFmpex.Options.Video.html#option_vbsf/0"},{"type":"function","title":"FFmpex.Options.Video.option_vbsf/1","doc":"","ref":"FFmpex.Options.Video.html#option_vbsf/1"},{"type":"function","title":"FFmpex.Options.Video.option_vcodec/0","doc":"","ref":"FFmpex.Options.Video.html#option_vcodec/0"},{"type":"function","title":"FFmpex.Options.Video.option_vcodec/1","doc":"","ref":"FFmpex.Options.Video.html#option_vcodec/1"},{"type":"function","title":"FFmpex.Options.Video.option_vdt/0","doc":"","ref":"FFmpex.Options.Video.html#option_vdt/0"},{"type":"function","title":"FFmpex.Options.Video.option_vdt/1","doc":"","ref":"FFmpex.Options.Video.html#option_vdt/1"},{"type":"function","title":"FFmpex.Options.Video.option_vf/0","doc":"","ref":"FFmpex.Options.Video.html#option_vf/0"},{"type":"function","title":"FFmpex.Options.Video.option_vf/1","doc":"","ref":"FFmpex.Options.Video.html#option_vf/1"},{"type":"function","title":"FFmpex.Options.Video.option_vframes/0","doc":"","ref":"FFmpex.Options.Video.html#option_vframes/0"},{"type":"function","title":"FFmpex.Options.Video.option_vframes/1","doc":"","ref":"FFmpex.Options.Video.html#option_vframes/1"},{"type":"function","title":"FFmpex.Options.Video.option_vn/0","doc":"","ref":"FFmpex.Options.Video.html#option_vn/0"},{"type":"function","title":"FFmpex.Options.Video.option_vn/1","doc":"","ref":"FFmpex.Options.Video.html#option_vn/1"},{"type":"function","title":"FFmpex.Options.Video.option_vstats/0","doc":"","ref":"FFmpex.Options.Video.html#option_vstats/0"},{"type":"function","title":"FFmpex.Options.Video.option_vstats/1","doc":"","ref":"FFmpex.Options.Video.html#option_vstats/1"},{"type":"function","title":"FFmpex.Options.Video.option_vstats_file/0","doc":"","ref":"FFmpex.Options.Video.html#option_vstats_file/0"},{"type":"function","title":"FFmpex.Options.Video.option_vstats_file/1","doc":"","ref":"FFmpex.Options.Video.html#option_vstats_file/1"},{"type":"function","title":"FFmpex.Options.Video.option_vtag/0","doc":"","ref":"FFmpex.Options.Video.html#option_vtag/0"},{"type":"function","title":"FFmpex.Options.Video.option_vtag/1","doc":"","ref":"FFmpex.Options.Video.html#option_vtag/1"},{"type":"module","title":"FFmpex.Options.Video.Libavformat","doc":"https://ffmpeg.org/ffmpeg-all.html#Format-Options","ref":"FFmpex.Options.Video.Libavformat.html"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_analyzeduration/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_analyzeduration/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_analyzeduration/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_analyzeduration/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_audio_preload/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_audio_preload/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_audio_preload/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_audio_preload/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_avioflags/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_avioflags/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_avioflags/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_avioflags/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_avoid_negative_ts/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_avoid_negative_ts/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_avoid_negative_ts/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_avoid_negative_ts/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_chunk_duration/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_chunk_duration/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_chunk_duration/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_chunk_duration/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_chunk_size/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_chunk_size/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_chunk_size/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_chunk_size/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_correct_ts_overflow/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_correct_ts_overflow/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_correct_ts_overflow/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_correct_ts_overflow/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_cryptokey/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_cryptokey/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_cryptokey/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_cryptokey/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_dump_separator/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_dump_separator/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_dump_separator/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_dump_separator/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_err_detect/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_err_detect/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_err_detect/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_err_detect/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_f_err_detect/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_f_err_detect/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_f_err_detect/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_f_err_detect/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fdebug/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fdebug/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fdebug/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fdebug/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fflags/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fflags/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fflags/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fflags/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_flush_packets/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_flush_packets/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_flush_packets/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_flush_packets/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_format_whitelist/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_format_whitelist/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_format_whitelist/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_format_whitelist/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fpsprobesize/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fpsprobesize/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_fpsprobesize/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_fpsprobesize/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_indexmem/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_indexmem/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_indexmem/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_indexmem/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_max_delay/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_max_delay/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_max_delay/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_max_delay/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_max_interleave_delta/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_max_interleave_delta/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_max_interleave_delta/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_max_interleave_delta/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_output_ts_offset/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_output_ts_offset/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_output_ts_offset/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_output_ts_offset/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_packetsize/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_packetsize/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_packetsize/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_packetsize/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_probesize/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_probesize/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_probesize/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_probesize/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_rtbufsize/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_rtbufsize/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_rtbufsize/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_rtbufsize/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_seek2any/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_seek2any/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_seek2any/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_seek2any/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_skip_initial_bytes/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_skip_initial_bytes/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_skip_initial_bytes/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_skip_initial_bytes/1"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_use_wallclock_as_timestamps/0","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_use_wallclock_as_timestamps/0"},{"type":"function","title":"FFmpex.Options.Video.Libavformat.option_use_wallclock_as_timestamps/1","doc":"","ref":"FFmpex.Options.Video.Libavformat.html#option_use_wallclock_as_timestamps/1"},{"type":"module","title":"FFmpex.Options.Video.Libx264","doc":"https://ffmpeg.org/ffmpeg-all.html#libx264_002c-libx264rgb","ref":"FFmpex.Options.Video.Libx264.html"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_8x8dct/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_8x8dct/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_8x8dct/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_8x8dct/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_ab/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_ab/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_ab/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_ab/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aq_mode/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aq_mode/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aq_mode/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aq_mode/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aq_strength/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aq_strength/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aq_strength/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aq_strength/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aud/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aud/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_aud/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_aud/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_avcintra_class/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_avcintra_class/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_avcintra_class/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_avcintra_class/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_bias/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_bias/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_bias/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_bias/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_pyramid/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_pyramid/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_pyramid/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_pyramid/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_strategy/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_strategy/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_b_strategy/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_b_strategy/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bf/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bf/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bf/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bf/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bframebias/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bframebias/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bframebias/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bframebias/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bluray_compat/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bluray_compat/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bluray_compat/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bluray_compat/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bufsize/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bufsize/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_bufsize/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_bufsize/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_cmp/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_cmp/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_cmp/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_cmp/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_coder/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_coder/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_coder/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_coder/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_cplxblur/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_cplxblur/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_cplxblur/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_cplxblur/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_crf/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_crf/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_crf/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_crf/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_crf_max/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_crf_max/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_crf_max/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_crf_max/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_deblock/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_deblock/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_deblock/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_deblock/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_direct_pred/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_direct_pred/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_direct_pred/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_direct_pred/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_fast_pskip/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_fast_pskip/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_fast_pskip/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_fast_pskip/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_fastfirstpass/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_fastfirstpass/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_fastfirstpass/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_fastfirstpass/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_flags2/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_flags2/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_flags2/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_flags2/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_flags/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_flags/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_flags/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_flags/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_forced_idr/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_forced_idr/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_forced_idr/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_forced_idr/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_g/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_g/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_g/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_g/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_i_qfactor/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_i_qfactor/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_i_qfactor/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_i_qfactor/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_intra_refresh/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_intra_refresh/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_intra_refresh/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_intra_refresh/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_keyint_min/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_keyint_min/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_keyint_min/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_keyint_min/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_level/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_level/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_level/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_level/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_maxrate/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_maxrate/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_maxrate/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_maxrate/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_mbtree/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_mbtree/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_mbtree/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_mbtree/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_me_range/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_me_range/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_me_range/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_me_range/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_minrate/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_minrate/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_minrate/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_minrate/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_mixed_refs/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_mixed_refs/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_mixed_refs/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_mixed_refs/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_motion_est/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_motion_est/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_motion_est/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_motion_est/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_movflags/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_movflags/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_movflags/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_movflags/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_nal_hrd/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_nal_hrd/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_nal_hrd/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_nal_hrd/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_partitions/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_partitions/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_partitions/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_partitions/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_passlogfile/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_passlogfile/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_passlogfile/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_passlogfile/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_preset/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_preset/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_preset/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_preset/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_profile/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_profile/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_profile/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_profile/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_psy/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_psy/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_psy/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_psy/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_psy_rd/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_psy_rd/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_psy_rd/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_psy_rd/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qdiff/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qdiff/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qdiff/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qdiff/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qmax/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qmax/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qmax/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qmax/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qmin/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qmin/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qmin/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qmin/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qp/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qp/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_qp/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_qp/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_rc_lookahead/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_rc_lookahead/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_rc_lookahead/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_rc_lookahead/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_refs/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_refs/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_refs/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_refs/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_sc_threshold/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_sc_threshold/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_sc_threshold/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_sc_threshold/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_slice_max_size/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_slice_max_size/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_slice_max_size/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_slice_max_size/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_ssim/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_ssim/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_ssim/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_ssim/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_stats/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_stats/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_stats/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_stats/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_subq/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_subq/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_subq/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_subq/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_threads/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_threads/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_threads/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_threads/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_trellis/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_trellis/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_trellis/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_trellis/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_tune/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_tune/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_tune/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_tune/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_vprofile/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_vprofile/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_vprofile/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_vprofile/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_weightb/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_weightb/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_weightb/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_weightb/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_weightp/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_weightp/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_weightp/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_weightp/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_wpredp/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_wpredp/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_wpredp/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_wpredp/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_x264_params/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_x264_params/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_x264_params/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_x264_params/1"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_x264opts/0","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_x264opts/0"},{"type":"function","title":"FFmpex.Options.Video.Libx264.option_x264opts/1","doc":"","ref":"FFmpex.Options.Video.Libx264.html#option_x264opts/1"},{"type":"module","title":"FFprobe","doc":"Execute `ffprobe` CLI commands.\n\n> `ffprobe` is a simple multimedia streams analyzer. You can use it to output\nall kinds of information about an input including duration, frame rate, frame size, etc.\nIt is also useful for gathering specific information about an input to be used in a script.\n\n(from https://trac.ffmpeg.org/wiki/FFprobeTips)","ref":"FFprobe.html"},{"type":"function","title":"FFprobe.duration/1","doc":"Get the duration in seconds, as a float.\n\nIf no duration (e.g., a still image), returns `:no_duration`.\nIf the file does not exist, returns { :error, :no_such_file }","ref":"FFprobe.html#duration/1"},{"type":"function","title":"FFprobe.format/1","doc":"Get the \"format\" map, containing general info for the specified file,\nsuch as number of streams, duration, file size, and more.\n\nIf the file does not exist, returns `{:error, :no_such_file}`.\nIf the file is a non media file, returns `{:error, :invalid_file}`.","ref":"FFprobe.html#format/1"},{"type":"function","title":"FFprobe.format_names/1","doc":"Get a list of formats for the file.\n\nIf the file does not exist, returns `{:error, :no_such_file}`.\nIf the file is a non media file, returns `{:error, :invalid_file}`.","ref":"FFprobe.html#format_names/1"},{"type":"function","title":"FFprobe.streams/1","doc":"Get a list a of streams from the file.\n\nIf the file does not exist, returns `{:error, :no_such_file}`.\nIf the file is a non media file, returns `{:error, :invalid_file}`.","ref":"FFprobe.html#streams/1"},{"type":"type","title":"FFprobe.format_map/0","doc":"","ref":"FFprobe.html#t:format_map/0"},{"type":"type","title":"FFprobe.streams_list/0","doc":"","ref":"FFprobe.html#t:streams_list/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"0.11.0 (2024-06-30) - Changelog","doc":"* Added `pattern_type` option. See `FFmpex.Options.Formats.Image2` module. ([#37](https://github.com/talklittle/ffmpex/pull/37))\n* Added Muxers/HLS options. See `FFmpex.Options.Muxers` module. ([#43](https://github.com/talklittle/ffmpex/pull/43))\n* Requires Elixir 1.12.","ref":"changelog.html#0-11-0-2024-06-30"},{"type":"extras","title":"0.10.0 (2022-01-14) - Changelog","doc":"* Allow FFprobe on remote URLs, instead of treating URLs as nonexistent files.","ref":"changelog.html#0-10-0-2022-01-14"},{"type":"extras","title":"0.9.0 (2021-11-16) - Changelog","doc":"* Run commands with [Rambo](https://github.com/jayjun/rambo) instead of erlexec, to address issues running in Docker.\n* Requires Elixir 1.9.","ref":"changelog.html#0-9-0-2021-11-16"},{"type":"extras","title":"0.8.2 (2021-11-15) - Changelog","doc":"* Fixed starting erlexec when running as root.","ref":"changelog.html#0-8-2-2021-11-15"},{"type":"extras","title":"0.8.1 (2021-11-11) - Changelog","doc":"* Fixed `SHELL` environment variable check for erlexec.","ref":"changelog.html#0-8-1-2021-11-11"},{"type":"extras","title":"0.8.0 (2021-11-10) - Changelog","doc":"* **Breaking change:** `execute/1` returns `{:ok, output}` instead of `:ok`.\n* Added `to_stdout/1` to direct ffmpeg output to a buffer instead of a file. Retrieve buffer in `{:ok, output}` result of `execute/1`. ([#31](https://github.com/talklittle/ffmpex/pull/31))","ref":"changelog.html#0-8-0-2021-11-10"},{"type":"extras","title":"0.7.3 (2020-07-09) - Changelog","doc":"* Relaxed Jason dependency so it can get all 1.x versions without mix.exs update.","ref":"changelog.html#0-7-3-2020-07-09"},{"type":"extras","title":"0.7.2 (2020-07-09) - Changelog","doc":"* Bumped Jason dependency to 1.2.","ref":"changelog.html#0-7-2-2020-07-09"},{"type":"extras","title":"0.7.1 (2019-11-26) - Changelog","doc":"* Changed to `-loop` instead of deprecated `-loop_input` and `-loop_output` options in `FFmpex.Options.Advanced`.","ref":"changelog.html#0-7-1-2019-11-26"},{"type":"extras","title":"0.7.0 (2019-09-05) - Changelog","doc":"* **Breaking change:** FFprobe API changes to return `{:ok, term}` or `{:error, atom}` from `format_names/1`, `format/1`, `streams/1`.\n* Changed `FFprobe.duration/1` to return `{:error, :no_such_file}` for nonexistent file, instead of raising MatchError.\n* Fixed FFprobe module to raise a clearer error message when FFmpeg not installed in system path.","ref":"changelog.html#0-7-0-2019-09-05"},{"type":"extras","title":"0.6.0 (2019-07-16) - Changelog","doc":"* Changed to Jason instead of Poison for JSON operations.","ref":"changelog.html#0-6-0-2019-07-16"},{"type":"extras","title":"0.5.2 (2018-04-10) - Changelog","doc":"* Added options `video_size`, `framerate`, `draw_mouse` in `FFmpex.Options.Devices.Libavdevice`.","ref":"changelog.html#0-5-2-2018-04-10"},{"type":"extras","title":"0.5.1 (2018-04-02) - Changelog","doc":"* Added `FFmpex.prepare/1` to retrieve arguments list, useful for inspection or passing to `Port.open/2`.","ref":"changelog.html#0-5-1-2018-04-02"},{"type":"extras","title":"0.5.0 (2018-03-26) - Changelog","doc":"* **Breaking change:** Changed output format of `FFprobe.format/1` to be cleaner, based on ffmpeg JSON output.\n  Specifically: `\"nb_programs\"`, `\"nb_streams\"`, and `\"probe_score\"` now contain integers instead of binaries;\n  and tags are stored in a `\"tags\"` sub-map instead of being individual entries prefixed with \"TAG:\".\n* Added `FFprobe.streams/1` to get a list of streams.\n* Depends on Poison 3.1.\n* Requires Elixir 1.4.","ref":"changelog.html#0-5-0-2018-03-26"},{"type":"extras","title":"0.4.1 (2017-03-22) - Changelog","doc":"* Fixed `FFprobe.format/1` for paths with spaces.","ref":"changelog.html#0-4-1-2017-03-22"},{"type":"extras","title":"0.4.0 (2016-12-03) - Changelog","doc":"* Added `FFmpex.Options.Video.Libavformat`.\n* Validate options context (input, output, global) as specified in FFmpeg docs.","ref":"changelog.html#0-4-0-2016-12-03"},{"type":"extras","title":"0.3.0 (2016-09-10) - Changelog","doc":"* **Breaking change:** `add_stream_specifier/2` takes a keyword list instead of `%StreamSpecifier{}`.\n* **Breaking change:** `execute/1` returns `:ok` or `{:error, {output, status}}`, instead of `{output, status}`.\n* Added `use FFmpex.Options` to conveniently import all options.","ref":"changelog.html#0-3-0-2016-09-10"},{"type":"extras","title":"0.2.1 (2016-08-17) - Changelog","doc":"* Added `FFprobe.format/1` and `FFprobe.format_names/1`.","ref":"changelog.html#0-2-1-2016-08-17"},{"type":"extras","title":"0.2.0 (2016-08-15) - Changelog","doc":"* Added `FFprobe` module. `FFprobe.duration/1` to get video duration.","ref":"changelog.html#0-2-0-2016-08-15"},{"type":"extras","title":"0.1.1 (2016-07-30) - Changelog","doc":"* Lower Elixir requirement to 1.0 (was 1.3).","ref":"changelog.html#0-1-1-2016-07-30"},{"type":"extras","title":"0.1.0 (2016-07-27) - Changelog","doc":"* First FFmpex release.\n* Specify per-file and per-stream options, and execute.\n* Non-exhaustive catalog of known options.","ref":"changelog.html#0-1-0-2016-07-27"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2016 Andrew Shu\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# FFmpex\n\n[![Build Status](https://github.com/talklittle/ffmpex/actions/workflows/ci.yml/badge.svg)](https://github.com/talklittle/ffmpex/actions?query=workflow%3ACI)\n[![Module Version](https://img.shields.io/hexpm/v/ffmpex.svg)](https://hex.pm/packages/ffmpex)\n\nAn Elixir wrapper for the FFmpeg command line interface.\n\nDocumentation: https://hexdocs.pm/ffmpex/","ref":"readme.html"},{"type":"extras","title":"Usage notes - Overview","doc":"The API is a builder, building up the list of options per-file, per-stream(-per-file), and globally.\n\nNote that adding options is backwards from using the ffmpeg CLI; when using ffmpeg CLI, you specify the options before each file. But with FFmpex (this library), you add the file/stream first, then add the relevant options afterward.","ref":"readme.html#usage-notes"},{"type":"extras","title":"Examples - Overview","doc":"```elixir\nimport FFmpex\nuse FFmpex.Options\n\ncommand =\n  FFmpex.new_command\n  |> add_global_option(option_y())\n  |> add_input_file(\"/path/to/input.avi\")\n  |> add_output_file(\"/path/to/output.avi\")\n    |> add_stream_specifier(stream_type: :video)\n      |> add_stream_option(option_b(\"64k\"))\n    |> add_file_option(option_maxrate(\"128k\"))\n    |> add_file_option(option_bufsize(\"64k\"))\n\n{:ok, output} = execute(command)\n```\n\nIt is possible to obtain ffmpeg's output with:\n```elixir\ncommand =\n  FFmpex.new_command\n  |> add_input_file(\"/path/to/input.mp4\")\n  |> to_stdout()\n  |> add_file_option(option_f(\"avi\"))\n\n{:ok, output} = execute(command)\n\ndo_something(output)\n```\n\nYou can use the `FFprobe` module to query for file info:\n\n```elixir\nFFprobe.duration(\"/path/to/input.avi\")\n# => result in seconds, e.g., 228.456939\n```\n\nSee [silent_video](https://github.com/talklittle/silent_video)\nand [thumbnex](https://github.com/talklittle/thumbnex)\nfor more usage examples.","ref":"readme.html#examples"},{"type":"extras","title":"Prerequisites - Overview","doc":"[FFmpeg](https://ffmpeg.org/) must be installed.","ref":"readme.html#prerequisites"},{"type":"extras","title":"Installation - Overview","doc":"Add `ffmpex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ffmpex, \"~> 0.11.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"You can specify some options in `config.exs`:\n\n```elixir\nconfig :ffmpex, ffmpeg_path: \"/path/to/ffmpeg\"\nconfig :ffmpex, ffprobe_path: \"/path/to/ffprobe\"\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Release notes - Overview","doc":"See the [Changelog](./CHANGELOG.md) for changes between versions.","ref":"readme.html#release-notes"},{"type":"extras","title":"Disclaimer - Overview","doc":"FFmpex is not affiliated with nor endorsed by the FFmpeg project.\n\nFFmpeg is a trademark of [Fabrice Bellard](http://www.bellard.org/), originator of the FFmpeg project.","ref":"readme.html#disclaimer"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2016 Andrew Shu\n\nFFmpex source code is licensed under the [MIT License](./LICENSE.md).","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}